==> taxware-banana-service-domain-0.0.109-sources.jar: com/xforceplus/taxwarebananaservice/metadata/PageMeta.java <==
package com.xforceplus.taxwarebananaservice.metadata;

/**
 *
 * @author ultraman
 * @since 2021-05-07
 */

public class PageMeta {
    public interface Invoice {
        static String code() {
            return "invoice";
        }
        static String name() {
            return "发票-Deprecated";
        }
    }
    public interface MachineManage {
        static String code() {
            return "machineManage";
        }
        static String name() {
            return "托管服务器管理";
        }
    }
    public interface TaxDeviceManage {
        static String code() {
            return "taxDeviceManage";
        }
        static String name() {
            return "税控设备管理";
        }
    }
    public interface TaxDeviceLocationManage {
        static String code() {
            return "taxDeviceLocationManage";
        }
        static String name() {
            return "税盘分布";
        }
    }
    public interface InvoiceSerialMonitor {
        static String code() {
            return "invoiceSerialMonitor";
        }
        static String name() {
            return "开票请求监控";
        }
    }
    public interface TcInvoiceSerialMonitor {
        static String code() {
            return "tcInvoiceSerialMonitor";
        }
        static String name() {
            return "开票请求监控(腾讯云)";
        }
    }
    public interface DeclareTaxFile {
        static String code() {
            return "declareTaxFile";
        }
        static String name() {
            return "报税文件";
        }
    }
    public interface CleanCard {
        static String code() {
            return "cleanCard";
        }
        static String name() {
            return "清卡反写";
        }
    }
    public interface OffLineMonitor {
        static String code() {
            return "offLineMonitor";
        }
        static String name() {
            return "实时掉线监控";
        }
    }
    public interface InvoiceMiMonitorPage {
        static String code() {
            return "invoiceMiMonitorPage";
        }
        static String name() {
            return "发票税盘监控";
        }
    }
    public interface TcInvoiceMiMonitorPage {
        static String code() {
            return "tcInvoiceMiMonitorPage";
        }
        static String name() {
            return "发票税盘监控(腾讯云)";
        }
    }
    public interface DeviceInventory {
        static String code() {
            return "deviceInventory";
        }
        static String name() {
            return "税盘库存";
        }
    }
    public interface TaxDeviceLoadPage {
        static String code() {
            return "taxDeviceLoadPage";
        }
        static String name() {
            return "税控设备负载均衡配置";
        }
    }
    public interface ClientUpdateManage {
        static String code() {
            return "clientUpdateManage";
        }
        static String name() {
            return "客户端升级配置管理";
        }
    }
    public interface FetchingStrategyPage {
        static String code() {
            return "fetchingStrategyPage";
        }
        static String name() {
            return "领票策略";
        }
    }
    public interface HistoryOfflineTraceMonitor {
        static String code() {
            return "historyOfflineTraceMonitor";
        }
        static String name() {
            return "历史掉线监控";
        }
    }
}

==> taxware-banana-service-domain-0.0.119-sources.jar: com/xforceplus/taxwarebananaservice/metadata/PageMeta.java <==
package com.xforceplus.taxwarebananaservice.metadata;

/**
 *
 * @author ultraman
 * @since 2021-06-28
 */

public class PageMeta {
    public interface Invoice {
        static String code() {
            return "invoice";
        }
        static String name() {
            return "发票-Deprecated";
        }
    }
    public interface MachineManage {
        static String code() {
            return "machineManage";
        }
        static String name() {
            return "托管服务器管理";
        }
    }
    public interface TaxDeviceManage {
        static String code() {
            return "taxDeviceManage";
        }
        static String name() {
            return "税控设备管理";
        }
    }
    public interface TaxDeviceLocationManage {
        static String code() {
            return "taxDeviceLocationManage";
        }
        static String name() {
            return "税盘分布";
        }
    }
    public interface InvoiceSerialMonitor {
        static String code() {
            return "invoiceSerialMonitor";
        }
        static String name() {
            return "开票请求监控";
        }
    }
    public interface TcInvoiceSerialMonitor {
        static String code() {
            return "tcInvoiceSerialMonitor";
        }
        static String name() {
            return "开票请求监控(腾讯云)";
        }
    }
    public interface DeclareTaxFile {
        static String code() {
            return "declareTaxFile";
        }
        static String name() {
            return "报税文件";
        }
    }
    public interface CleanCard {
        static String code() {
            return "cleanCard";
        }
        static String name() {
            return "清卡反写";
        }
    }
    public interface OffLineMonitor {
        static String code() {
            return "offLineMonitor";
        }
        static String name() {
            return "实时掉线监控";
        }
    }
    public interface InvoiceMiMonitorPage {
        static String code() {
            return "invoiceMiMonitorPage";
        }
        static String name() {
            return "实时发票税盘积压监控";
        }
    }
    public interface TcInvoiceMiMonitorPage {
        static String code() {
            return "tcInvoiceMiMonitorPage";
        }
        static String name() {
            return "实时发票税盘积压监控(腾讯云)";
        }
    }
    public interface DeviceInventory {
        static String code() {
            return "deviceInventory";
        }
        static String name() {
            return "税盘库存";
        }
    }
    public interface TaxDeviceLoadPage {
        static String code() {
            return "taxDeviceLoadPage";
        }
        static String name() {
            return "税控设备负载均衡配置";
        }
    }
    public interface ClientUpdateManage {
        static String code() {
            return "clientUpdateManage";
        }
        static String name() {
            return "客户端升级配置管理";
        }
    }
    public interface FetchingStrategyPage {
        static String code() {
            return "fetchingStrategyPage";
        }
        static String name() {
            return "领票策略";
        }
    }
    public interface HistoryOfflineTraceMonitor {
        static String code() {
            return "historyOfflineTraceMonitor";
        }
        static String name() {
            return "历史掉线监控";
        }
    }
    public interface HistoryDelayMonitor {
        static String code() {
            return "historyDelayMonitor";
        }
        static String name() {
            return "历史税盘积压监控(阿里云)";
        }
    }
    public interface TcHistoryDelayMonitor {
        static String code() {
            return "tcHistoryDelayMonitor";
        }
        static String name() {
            return "历史税盘积压监控(腾讯云)";
        }
    }
}
